@@ -1,11 +1,8 @@
 import jinja2
-import logging
+from . import log
 import os
-from bookbook.latex import combine_and_convert
-from pathlib import Path
 
-logging.basicConfig(level=logging.INFO)
-log = logging.getLogger(__name__)
+from pathlib import Path
 
 
 class BookContext:
@@ -60,6 +57,15 @@ class Book:
         with BookContext(self.bookbook_filename, bookbook_template,
                          self.output_path):
             # Call bookbook
+            try:
+                from bookbook.latex import combine_and_convert
+            except ModuleNotFoundError:
+                msg = """\
+bookbook is not installed. Due to a change in nbconvert install this forked version:
+pip install git+https://github.com/boileaum/bookbook.git@master
+"""
+                log.error(msg)
+                exit(msg)
             combine_and_convert(Path.cwd(),
                                 Path(self.book_title),
                                 pdf=True,
